package com.game.business.task;

import com.alibaba.fastjson2.JSONArray;
import com.alibaba.fastjson2.JSONObject;
import com.game.business.domain.*;
import com.game.business.service.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

@Component
public class AppGameBettingTask {

    @Autowired
    private IAppGameBettingService appGameBettingService;

    @Autowired
    private IAppUserService appUserService;

    @Autowired
    private IFinTranRecordService finTranRecordService;

    @Autowired
    private IAppGameLotteryService appGameLotteryService;

    @Autowired
    private IAppGameService appGameService;

    @Autowired
    private IAppGameClassifyService appGameClassifyService;

    @Async("asyncExecutor")
    public void gameDataTask(String message){

        JSONArray dataArry = JSONArray.parseArray(message);

        Integer type = null;

        for (int i = 0; i < dataArry.size(); i++) {
            JSONObject jsonObject = dataArry.getJSONObject(i);
            if(jsonObject.containsKey("type")){
                type = jsonObject.getInteger("type");
                break;
            }
        }

        if(type == null){
            System.out.println("游戏socket推送类型为空。");
            return;
        }

        // 更新倒计时
        if(type == 1){

            JSONArray gameDataArry = null;
            String time = null;
            String classCode = null;
            for (int i = 0; i < dataArry.size(); i++) {
                JSONObject jsonObject = dataArry.getJSONObject(i);
                if(jsonObject.containsKey("data")){
                    gameDataArry = jsonObject.getJSONArray("data");
                }
                if(jsonObject.containsKey("time")){
                    time = jsonObject.getString("time");
                }
                if(jsonObject.containsKey("id")){
                    classCode = jsonObject.getString("id");
                }
            }

            if(classCode == null){
                System.out.println("游戏socket推送倒计时，平台ID为空。");
                return;
            }

            if(gameDataArry == null){
                System.out.println("游戏socket推送倒计时，data对象为空。");
                return;
            }

            if(time == null || time.trim().isEmpty()){
                System.out.println("游戏socket推送倒计时，time为空。");
                return;
            }

            AppGameClassify appGameClassify = appGameClassifyService.getByCode(classCode);
            if(appGameClassify == null){
                System.out.println("开奖游戏平台不存在：" + classCode);
                return;
            }

            List<AppGame> appGameList = appGameService.selectAppGameByClassId(appGameClassify.getId());
            if(appGameList == null || appGameList.isEmpty()){
                System.out.println("开奖游戏平台没有游戏：" + classCode);
                return;
            }
            Map<String, List<AppGame>> codeGameMap = appGameList.stream().collect(Collectors.groupingBy(AppGame::getCode));

            for (int i = 0; i < gameDataArry.size(); i++) {
                JSONObject jsonObject = gameDataArry.getJSONObject(i);
                String gameCode = jsonObject.getString("id");
                if(gameCode == null){
                    System.out.println("游戏socket推送倒计时，游戏id为空。");
                    continue;
                }
                if(!codeGameMap.containsKey(gameCode)){
                    System.out.println("开奖游戏不存在：" + gameCode);
                    continue;
                }
                AppGame appGame = codeGameMap.get(gameCode).get(0);
                appGame.setGameTime(time);
                appGameService.updateAppGame(appGame);
            }
            return;
        }

        if(type != 2 && type != 3){
            return;
        }

        JSONArray gameArry = null;
        String classCode = null;
        for (int i = 0; i < dataArry.size(); i++) {
            JSONObject jsonObject = dataArry.getJSONObject(i);
            if(jsonObject.containsKey("gameTypeSortArrayVOS")){
                gameArry = jsonObject.getJSONArray("gameTypeSortArrayVOS");
            }
            if(jsonObject.containsKey("id")){
                classCode = jsonObject.getString("id");
            }
        }

        if(gameArry == null){
            System.out.println("游戏socket推送期号或开奖，gameTypeSortArrayVOS对象为空。");
            return;
        }

        if(classCode == null){
            System.out.println("游戏socket推送期号或开奖，平台ID为空。");
            return;
        }

        AppGameClassify appGameClassify = appGameClassifyService.getByCode(classCode);
        if(appGameClassify == null){
            System.out.println("开奖游戏平台不存在：" + classCode);
        }

        List<AppGame> appGameList = appGameService.selectAppGameByClassId(appGameClassify.getId());
        if(appGameList == null || appGameList.isEmpty()){
            System.out.println("开奖游戏平台没有游戏：" + classCode);
            return;
        }
        Map<String, List<AppGame>> codeGameMap = appGameList.stream().collect(Collectors.groupingBy(AppGame::getCode));

        for (int i = 0; i < gameArry.size(); i++) {
            JSONObject gameLotteryObject = gameArry.getJSONObject(i);
            String gameCode = gameLotteryObject.getString("id");

            if(gameCode == null){
                System.out.println("游戏socket推送期号或开奖，游戏ID为空。");
                return;
            }

            if(!codeGameMap.containsKey(gameCode)){
                System.out.println("开奖游戏不存在：" + gameCode);
                continue;
            }
            AppGame appGame = codeGameMap.get(gameCode).get(0);

            String gameDate = gameLotteryObject.getString("gameDate");
            if(gameDate == null){
                System.out.println("游戏socket推送期号或开奖，期号为空。");
                return;
            }

            if(type == 3){
                appGame.setGameDate(gameDate);
                appGameService.updateAppGame(appGame);
                continue;
            }

            long count = appGameLotteryService.selectCount(appGame.getClassifyId(), appGame.getId(), gameDate);

            if(count > 0){
                System.out.println("游戏socket推送开奖，当前期已开过将，游戏编码：" + gameCode + "，期号：" + gameDate);
                continue;
            }

            Integer isLottery = gameLotteryObject.getInteger("isLottery");
            String gameLotterySucc = gameLotteryObject.getString("gameLotterySucc");

            // 保存开奖记录
            AppGameLottery appGameLottery = new AppGameLottery();
            appGameLottery.setGameId(appGame.getId());
            appGameLottery.setClassId(appGame.getClassifyId());
            appGameLottery.setGameDate(gameDate);
            appGameLottery.setIsLottery(isLottery);
            appGameLottery.setGameRecordDate(new Date());
            appGameLottery.setGameLotterySucc(gameLotterySucc);
            appGameLotteryService.save(appGameLottery);

            if(isLottery != 1){
                continue;
            }

            this.gameBettingTask(appGameClassify.getId(), appGame.getId(), gameDate, gameLotterySucc);
        }

    }

    public void gameBettingTask(Long classId, Long gameId, String gameDate, String bettingItem){

        List<AppGameBetting> list = appGameBettingService.getIsWinning(classId, gameId, gameDate, 0);

        if(list == null || list.isEmpty()){
            return;
        }

        for (int i = 0; i < list.size(); i++) {
            AppGameBetting appGameBetting = list.get(i);
            appGameBetting.setUpdateTime(new Date());
            if(!appGameBetting.getBettingItem().equals(bettingItem)){
                appGameBetting.setIsWinning(2);
                appGameBettingService.updateById(appGameBetting);
                continue;
            }

            AppUser appUser = appUserService.selectAppUserByUserid(appGameBetting.getUserId());
            if(appUser == null){
                appGameBetting.setIsWinning(1);
                appGameBettingService.updateById(appGameBetting);
                continue;
            }

            // 更新用户余额
            appUser.setDiamondCoin(appUser.getDiamondCoin() + (appGameBetting.getBettingAmount() * appGameBetting.getBettingMultiple()) );
            appUser.setDiamondCoinTotal(appUser.getDiamondCoinCashTotal() + (appGameBetting.getBettingAmount() * appGameBetting.getBettingMultiple()));
            appUserService.updateAppUser(appUser);

            appGameBetting.setIsWinning(1);
            appGameBettingService.updateById(appGameBetting);

            FinTranRecord finTranRecord = new FinTranRecord();

            finTranRecord.setAfterCoin(appUser.getCoin());
            finTranRecord.setCoinChange(0.00);

            finTranRecord.setAfterMoney(0.00);
            finTranRecord.setMoneyChange(0.00);

            finTranRecord.setAfterDiamondCoin(appUser.getDiamondCoin());
            finTranRecord.setDiamondCoinChange(appGameBetting.getBettingAmount());

            finTranRecord.setAfterTicket(0.00);
            finTranRecord.setTicketChange(0.00);

            finTranRecord.setToUid(appUser.getUserid());
            finTranRecord.setUid(appUser.getUserid());

            finTranRecord.setSceneId1(0L);
            finTranRecord.setSceneId2(null);
            finTranRecord.setSceneType(0L);

            finTranRecord.setTranGroupId(appGameBetting.getId());
            finTranRecord.setTranType1(17L);
            finTranRecord.setTranType2(200L);
            finTranRecord.setTranType3(20001L);

            finTranRecord.setRemarks("游戏中奖");

            finTranRecord.setConsumptionCoin(appGameBetting.getBettingAmount());
            finTranRecord.setConsumptionMoney(0.00);
            finTranRecord.setCommissionRelatedUid(0L);
            finTranRecord.setAgentId(appUser.getAgentId());

            finTranRecord.setCreateTime(new Date());

            finTranRecord.setCurrencyType(4L);

            finTranRecord.setFromUid(0L);
            finTranRecord.setGoodsId(0L);
            finTranRecord.setGuildId(0L);
            finTranRecord.setManagerCoId(0L);
            finTranRecord.setManagerId(0L);

            finTranRecord.setPerc(0.00);
            finTranRecord.setProId(0L);
            finTranRecord.setProCount(0L);

            finTranRecord.setOrderId(appGameBetting.getId());

            finTranRecordService.insertFinTranRecord(finTranRecord);
        }
    }
}
